@@ -1,10 +1,10 @@
 """
-$Id: Class.py,v 1.6 2002/04/23 12:52:19 anthonybaxter Exp $
+$Id: Class.py,v 1.6.4.2 2011/03/23 01:42:07 customdesigned Exp $
 
  This file is part of the pydns project.
  Homepage: http://pydns.sourceforge.net
 
- This code is covered by the standard Python License.
+ This code is covered by the standard Python License. See LICENSE for details.
 
  CLASS values (section 3.2.4)
 """
@@ -35,6 +35,12 @@ def classstr(klass):
 
 #
 # $Log: Class.py,v $
+# Revision 1.6.4.2  2011/03/23 01:42:07  customdesigned
+# Changes from 2.3 branch
+#
+# Revision 1.6.4.1  2011/02/18 19:35:22  customdesigned
+# Python3 updates from Scott Kitterman
+#
 # Revision 1.6  2002/04/23 12:52:19  anthonybaxter
 # cleanup whitespace.
 #
